@@ -2,7 +2,7 @@
  * @file   biblio.c
  * @brief
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -32,6 +32,7 @@
 #include <sys/stat.h> 
 
 #include "biblio.h"
+#include "constants.h"
 #include "utils.h"
 #include "latex.h"
 #include "environment.h"
@@ -73,7 +74,7 @@ gboolean biblio_detect_bibliography (GuBiblio* bc, GuEditor* ec) {
     if (g_regex_match (bib_regex, content, 0, &match_info)) {
         result = g_match_info_fetch_all (match_info);
         if (result[1]) {
-            if (g_strcmp0 (result[1] +strlen (result[1]) -4, ".bib") != 0)
+            if (!STR_EQU (result[1] +strlen (result[1]) -4, ".bib"))
                 bibfn = g_strconcat (result[1], ".bib", NULL);
             else
                 bibfn = g_strdup (result[1]);
@@ -101,15 +102,13 @@ gboolean biblio_compile_bibliography (GuBiblio* bc, GuEditor* ec, GuLatex* lc) {
 
     if (g_find_program_in_path ("bibtex")) {
         gboolean success = FALSE;
-        char* command = g_strdup_printf ("cd \"%s\";"
-                                         "env openout_any=a bibtex \"%s\"",
-                                         dirname,
-                                         auxname);
+        char* command = g_strdup_printf ("%s bibtex \"%s\"",
+                                         C_TEXSEC, auxname);
                                          
         g_free (auxname);
         latex_update_workfile (lc, ec);
         latex_update_auxfile (lc, ec);
-        Tuple2 res = utils_popen_r (command);
+        Tuple2 res = utils_popen_r (command, dirname);
         gtk_widget_set_tooltip_text (GTK_WIDGET (bc->progressbar),
                 (gchar*)res.second);
         g_free (command);
@@ -147,10 +146,12 @@ int biblio_parse_entries (GuBiblio* bc, gchar *bib_content) {
         (G_REGEX_CASELESS | G_REGEX_DOTALL), 0, NULL);
       
     subregex_ident = g_regex_new ("@.+{([^,]+),", 0, 0, NULL);
-    subregex_title = g_regex_new ("[^book]title[\\s]*=[\\s]*(.*)", 0, 0, NULL);
-    subregex_author = g_regex_new ("author[\\s]*=[\\s]*(.*)", 0, 0, NULL);
-    subregex_year = g_regex_new ("year[\\s]*=[\\s]*[{|\"]?([1|2][0-9]{3})", 0,
-            0, NULL);
+    subregex_title = g_regex_new 
+		("[^book]title[\\s]*=[\\s]*(.*)", G_REGEX_CASELESS, 0, NULL);
+    subregex_author = g_regex_new 
+		("author[\\s]*=[\\s]*(.*)", G_REGEX_CASELESS, 0, NULL);
+    subregex_year = g_regex_new 
+		("year[\\s]*=[\\s]*[{|\"]?([1|2][0-9]{3})", G_REGEX_CASELESS, 0, NULL);
     regex_formatting = g_regex_new ("[{|}|\"|,|\\$]", 0, 0, NULL);
     
     
