@@ -2,7 +2,7 @@
  * @file    editor.c
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -185,6 +185,13 @@ void editor_fileinfo_update (GuEditor* ec, const gchar* filename) {
 
     ec->fdname = g_build_filename (C_TMPDIR, "gummi_XXXXXX", NULL);
     ec->workfd = g_mkstemp (ec->fdname);
+    
+    // This is required for Windows 7, but not for Linux. It may also
+    // be the proper way for *nix, but I don't want to change this
+    // crucial piece of code at this stage of development -alexander
+    #ifdef WIN32
+		close(ec->workfd);
+	#endif
 
     if (filename) {
         gchar* base = g_path_get_basename (filename);
@@ -409,7 +416,7 @@ void editor_set_selection_textstyle (GuEditor* ec, const gchar* type) {
 
     /* select style */
     for (i = 0; i < style_size; ++i)
-        if (0 == g_strcmp0 (style[i][0], type)) {
+        if (STR_EQU (style[i][0], type)) {
             selected = i;
             break;
         }
