@@ -2,7 +2,7 @@
  * @file    gui-main.c
  * @brief
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -71,7 +71,8 @@ const gchar* insens_widgets_str[] = {
     "menu_delete", "menu_selectall", "menu_preferences", "menu_find",
     "menu_prev", "menu_next", "menu_pdfcompile", "menu_compileopts",
     "menu_runmakeindex", "menu_runbibtex", "menu_docstat", "menu_spelling",
-    "menu_snippets", "menu_edit", "menu_document", "menu_search"
+    "menu_snippets", "menu_edit", "menu_document", "menu_search",
+    "menu_cleanup"
 };
 
 
@@ -87,8 +88,8 @@ GummiGui* gui_init (GtkBuilder* builder) {
 
     g->mainwindow =
         GTK_WINDOW (gtk_builder_get_object (builder, "mainwindow"));
-    g->toolbar =
-        GTK_HBOX (gtk_builder_get_object (builder, "toolbar"));
+    g->toolbar = 
+        GTK_WIDGET (gtk_builder_get_object (builder, "maintoolbar"));
     g->statusbar =
         GTK_STATUSBAR (gtk_builder_get_object (builder, "statusbar"));
     g->rightpane =
@@ -182,11 +183,11 @@ GummiGui* gui_init (GtkBuilder* builder) {
     }
     if (config_get_value ("toolbar")) {
         gtk_check_menu_item_set_active (g->menu_toolbar, TRUE);
-        gtk_widget_show (GTK_WIDGET (g->toolbar));
+        gtk_widget_show (g->toolbar);
     } else {
         config_set_value ("toolbar", "False");
         gtk_check_menu_item_set_active (g->menu_toolbar, FALSE);
-        gtk_widget_hide (GTK_WIDGET (g->toolbar));
+        gtk_widget_hide (g->toolbar);
     }
 
     if (config_get_value ("statusbar")) {
@@ -230,19 +231,56 @@ GummiGui* gui_init (GtkBuilder* builder) {
     return g;
 }
 
+
+G_MODULE_EXPORT
+gboolean on_w32button_clicked (GtkWidget* widget, void* user) {
+	#ifdef WIN32
+		gtk_widget_hide (gui->w32window);
+	#endif
+	return TRUE;
+}
+
+#ifdef WIN32
+gboolean w32popup_wait_event (void *builder) {
+
+	const gchar* count = gtk_label_get_text (GTK_LABEL (gui->w32label));
+	gint number = atoi (count) - 1;
+	
+	if (number == 0) {
+
+		gtk_label_set_text (GTK_LABEL (gui->w32label), "");	
+		gtk_widget_set_sensitive (gui->w32button, TRUE);
+		return FALSE;
+	}
+	gtk_label_set_text (GTK_LABEL (gui->w32label), 
+						g_strdup_printf("%d", number));
+	return TRUE;
+}
+#endif
+
 void gui_main (GtkBuilder* builder) {
     gtk_builder_connect_signals (builder, NULL);
     gtk_widget_show_all (GTK_WIDGET (gui->mainwindow));
 
-
-    //GtkWidget *tmp = GTK_WIDGET (gtk_builder_get_object (builder, "svnpopup"));
-    //gtk_widget_show (tmp);
+	#ifdef WIN32
+    gui->w32window = 
+			GTK_WIDGET (gtk_builder_get_object (builder, "w32popup"));
+	gui->w32button = 
+			GTK_WIDGET (gtk_builder_get_object (builder, "w32button"));
+	gui->w32label = 
+			GTK_WIDGET (gtk_builder_get_object (builder, "w32label"));
+    gtk_widget_show (gui->w32window);
+    
+    g_timeout_add_seconds (1, w32popup_wait_event, NULL);
+    #endif
 
     gdk_threads_enter();
     gtk_main ();
     gdk_threads_leave();
 }
 
+
+
 G_MODULE_EXPORT
 void on_menu_autosync_toggled (GtkCheckMenuItem *menu_autosync, void* user) {
     if (gtk_check_menu_item_get_active(menu_autosync)) {
@@ -255,6 +293,8 @@ void on_menu_autosync_toggled (GtkCheckMenuItem *menu_autosync, void* user) {
 G_MODULE_EXPORT
 void on_tab_notebook_switch_page(GtkNotebook *notebook, GtkWidget *nbpage,
                                  int pagenr, void *data) {
+    /* Kill typesetter command */
+    motion_kill_typesetter(gummi->motion);
 
     /* set the active tab/editor pointers */
     tabmanager_set_active_tab (pagenr);
@@ -307,50 +347,56 @@ void gui_set_window_title (const gchar* filename, const gchar* text) {
 }
 
 
-void gui_open_file (const gchar* filename) {
-    gint ret = 0;
-    gchar* basename = NULL;
-    gchar* dirname = NULL;
-    gchar* prev_workfile =  NULL;
 
+void on_recovery_infobar_response (GtkInfoBar* bar, gint res, gpointer filename) {
+    gchar* prev_workfile = iofunctions_get_swapfile (filename);
+    
+    if (res == GTK_RESPONSE_YES) {
+        tabmanager_set_content (A_LOAD_OPT, filename, prev_workfile);
+    }
+    else { // NO
+        tabmanager_set_content (A_LOAD, filename, NULL);
+    }
+    gui_recovery_mode_disable (bar);
+}
+
+void gui_recovery_mode_enable (GuTabContext* tab, const gchar* filename) {
+    gchar* prev_workfile = iofunctions_get_swapfile (filename);
+
+    slog (L_WARNING, "Swap file `%s' found.\n", prev_workfile);
+    gchar* msg = g_strdup_printf (_("Swap file exists for %s, "
+				"do you want to recover from it?"), filename);
+    gtk_label_set_text (GTK_LABEL (tab->page->barlabel), msg);
+    g_free (msg);
+    
+    gchar* data = g_strconcat (filename, NULL);
+    tab->page->infosignal = 
+        g_signal_connect (g_active_tab->page->infobar, "response",
+        G_CALLBACK (on_recovery_infobar_response), (gpointer)data);
+        
+    gtk_widget_set_sensitive (GTK_WIDGET (tab->editor->view), FALSE);
+    gtk_widget_show (tab->page->infobar);
+}
+
+void gui_recovery_mode_disable (GtkInfoBar *infobar) {
+    gint id = g_active_tab->page->infosignal;
+    g_signal_handler_disconnect (infobar, id);
+
+    gtk_widget_hide (GTK_WIDGET(infobar));
+    gtk_widget_set_sensitive (GTK_WIDGET (g_active_editor->view), TRUE);
+}
+
+void gui_open_file (const gchar* filename) {
     if (!g_file_test(filename, G_FILE_TEST_EXISTS)) {
         slog(L_G_ERROR, "Failed to open file '%s': No such file or "
                 "directory\n", filename);
         return;
     }
 
-    basename = g_path_get_basename (filename);
-    dirname = g_path_get_dirname (filename);
-    prev_workfile = g_strdup_printf ("%s%c.%s.swp", dirname,
-            G_DIR_SEPARATOR, basename);
-
-    /* destroy previous file info context, be careful not to place this
-     * line before the previewgui_stop_preview, else if the user is using
-     * the real_time compile scheme, the compile scheme functions can
-     * access fileinfo */
-
-    /* Check if swap file exists and try to recover from it */
-    if (utils_path_exists (prev_workfile)) {
-        slog (L_WARNING, "Swap file `%s' found.\n", prev_workfile);
-        gchar* message = g_strdup_printf (_("Swap file exits for %s, do you "
-                "want to recover from it?"), filename);
-
-        ret = utils_yes_no_dialog (message);
-        if (GTK_RESPONSE_YES == ret)
-            tabmanager_create_tab (A_LOAD_OPT, filename, prev_workfile);
-        g_free (message);
-    }
-
-    g_free (dirname);
-    g_free (basename);
-    g_free (prev_workfile);
-
-
-    if (GTK_RESPONSE_YES != ret)
-        tabmanager_create_tab (A_LOAD, filename, NULL);
-
-    if (!gtk_widget_get_sensitive (GTK_WIDGET (gui->rightpane)))
+    tabmanager_create_tab (A_LOAD, filename, NULL);
+    if (!gtk_widget_get_sensitive (GTK_WIDGET (gui->rightpane))) {
         gui_set_hastabs_sensitive (TRUE);
+	}
 }
 
 void gui_save_file (GuTabContext* tab, gboolean saveas) {
@@ -363,7 +409,7 @@ void gui_save_file (GuTabContext* tab, gboolean saveas) {
     if (saveas || !(filename = tab->editor->filename)) {
         if ((filename = get_save_filename (TYPE_LATEX))) {
             new = TRUE;
-            if (g_strcmp0 (filename + strlen (filename) -4, ".tex")) {
+            if (!STR_EQU (filename + strlen (filename) -4, ".tex")) {
                 prev = filename;
                 filename = g_strdup_printf ("%s.tex", filename);
                 g_free (prev);
@@ -518,6 +564,14 @@ void on_template_rowitem_edited (GtkWidget* widget, gchar *path, gchar* filenm,
     g_free (filepath);
 }
 
+G_MODULE_EXPORT 
+void on_template_cursor_changed (GtkTreeView *tree, gpointer data) {
+    if (!gtk_tree_view_get_selection (tree) == 0) {
+        gtk_widget_set_sensitive (gummi->templ->template_open, TRUE);
+    }
+}
+    
+
 G_MODULE_EXPORT
 void on_bibcolumn_clicked (GtkWidget* widget, void* user) {
     gint id = gtk_tree_view_column_get_sort_column_id
@@ -798,9 +852,20 @@ void file_dialog_set_filter (GtkFileChooser* dialog, GuFilterType type) {
             gtk_file_chooser_set_filter (dialog, filter);
             break;
 
-        case TYPE_IMAGE:
-            gtk_file_filter_set_name (filter, _("Image files"));
-            gtk_file_filter_add_mime_type (filter, "image/*");
+        case TYPE_IMAGE: 
+            /* Only \insertgraphics uses this section now. Make sure 
+             * the patterns & mimes are correct before assigning it
+			 * for other functions */
+            gtk_file_filter_set_name (filter, _("Supported Image files"));
+            
+            /* Pdflatex supports different formats than pure latex */
+            if (latex_method_active ("texpdf")) {
+				gtk_file_filter_add_pattern (filter, "*.jpg");
+				gtk_file_filter_add_pattern (filter, "*.jpeg");
+				gtk_file_filter_add_pattern (filter, "*.png");
+				gtk_file_filter_add_pattern (filter, "*.pdf");
+			}
+			gtk_file_filter_add_pattern (filter, "*.eps");
             gtk_file_chooser_add_filter (dialog, filter);
             gtk_file_chooser_set_filter (dialog, filter);
             break;
@@ -825,7 +890,7 @@ void add_to_recent_list (const gchar* filename) {
     gint i = 0;
     /* check if it already exists */
     for (i = 0; i < 5; ++i)
-        if (0 == g_strcmp0 (filename, gui->recent_list[i]))
+        if (STR_EQU (filename, gui->recent_list[i]))
             return;
 
     /* add to recent list */
@@ -845,7 +910,7 @@ void display_recent_files (GummiGui* gui) {
         gtk_widget_hide (GTK_WIDGET (gui->recent[i]));
 
     for (i = 0; i < RECENT_FILES_NUM; ++i) {
-        if (0 != g_strcmp0 (gui->recent_list[i], "__NULL__")) {
+        if (!STR_EQU (gui->recent_list[i], "__NULL__")) {
             basename = g_path_get_basename (gui->recent_list[i]);
             tstr = g_strdup_printf ("%d. %s", count + 1, basename);
             gtk_menu_item_set_label (gui->recent[i], tstr);
