@@ -2,7 +2,7 @@
  * @file   gui-main.h
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -77,7 +77,7 @@ struct _GummiGui {
     GtkTextView* errorview;
         GtkVBox* rightpane;
 
-    GtkHBox* toolbar;
+    GtkWidget* toolbar;
     GtkStatusbar* statusbar;
     GtkToggleToolButton* previewoff;
     GtkCheckMenuItem* menu_spelling;
@@ -95,6 +95,12 @@ struct _GummiGui {
     GtkMenuItem* menu_runbibtex;
     GtkMenuItem* menu_runmakeindex;
     
+    #ifdef WIN32
+		GtkWidget* w32label;
+		GtkWidget* w32button;
+		GtkWidget* w32window;
+    #endif
+    
     guint statusid;
     gchar* recent_list[5];
 };
@@ -138,6 +144,7 @@ void on_button_template_open_clicked (GtkWidget* widget, void* user);
 void on_button_template_close_clicked (GtkWidget* widget, void* user);
 void on_template_rowitem_edited (GtkWidget* widget, gchar *path, gchar* filenm,
         void* user);
+void gui_recover_from_swapfile (const gchar* filename);
 void on_menu_autosync_toggled (GtkCheckMenuItem *menu_autosync, void* user);
 
 void on_button_biblio_compile_clicked (GtkWidget* widget, void* user);
@@ -147,6 +154,10 @@ void on_bibreference_clicked (GtkTreeView* view, GtkTreePath* Path,
 void on_biblio_filter_changed (GtkWidget* widget, void* user);
 gboolean on_bibprogressbar_update (void* user);
 
+void on_recovery_infobar_response (GtkInfoBar* bar, gint res, gpointer filename);
+void gui_recovery_mode_enable (GuTabContext* tab, const gchar* filename);
+void gui_recovery_mode_disable (GtkInfoBar *infobar);
+
 /* misc functions */
 gchar* get_open_filename (GuFilterType type);
 gchar* get_save_filename (GuFilterType type);
