@@ -2,7 +2,7 @@
  * @file   gui-menu.c
  * @brief
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -30,10 +30,12 @@
 #include "gui-menu.h"
 
 #include "configfile.h"
+#include "constants.h"
 #include "editor.h"
 #include "environment.h"
 #include "external.h"
 #include "gui-main.h"
+#include "motion.h"
 #include "project.h"
 #include "update.h"
 
@@ -55,14 +57,46 @@ GuMenuGui* menugui_init (GtkBuilder* builder) {
     m->menu_projclose = GTK_MENU_ITEM(
                         gtk_builder_get_object (builder, "menu_projclose"));
     
+    #ifdef WIN32
+    /* please do not enable for nix, it has no place on a free OS ;)*/
+    GtkWidget* donate = 
+		gtk_menu_item_new_with_label ("Support this Project");
+    GtkWidget* helpmenu = 
+		GTK_WIDGET (gtk_builder_get_object (builder, "menu11"));
+    gtk_menu_prepend (GTK_MENU (helpmenu), donate);
+    gtk_signal_connect_object (GTK_OBJECT (donate), "activate",
+                               GTK_SIGNAL_FUNC (on_menu_donate_activate),
+                               NULL);
+    #endif
+    
     return m;
 }
 
+#ifdef WIN32
+G_MODULE_EXPORT
+void on_menu_donate_activate (GtkWidget* widget, void* user) {
+	//TODO: enhance
+	GtkWidget* dialog;
+    dialog = gtk_message_dialog_new (NULL, 
+        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+        GTK_MESSAGE_INFO,
+        GTK_BUTTONS_OK,
+        "Gummi is released as free open-source software under the MIT "
+        "license. Development is carried out and continued as a spare "
+        "time activity. \nIf you are interested in supporting this "
+        "project with a donation, please visit our official website. "
+        "Thank you!");
+    gtk_window_set_title (GTK_WINDOW (dialog), "Support this project");
+    gtk_dialog_run (GTK_DIALOG (dialog));      
+    gtk_widget_destroy (dialog);
+}
+#endif
+
 /*******************************************************************************
  * FILE MENU                                                                   *
  ******************************************************************************/
 
- G_MODULE_EXPORT
+G_MODULE_EXPORT
 void on_menu_new_activate (GtkWidget *widget, void* user) {
     if (!gtk_widget_get_sensitive (GTK_WIDGET (gui->rightpane)))
         gui_set_hastabs_sensitive (TRUE);
@@ -70,7 +104,7 @@ void on_menu_new_activate (GtkWidget *widget, void* user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_template_activate (GtkWidget *widget, void * user) {
+void on_menu_template_activate (GtkWidget *widget, void *user) {
     gtk_list_store_clear (gummi->templ->list_templates);
     template_setup (gummi->templ);
     gtk_widget_show_all (GTK_WIDGET (gummi->templ->templatewindow));
@@ -99,7 +133,7 @@ void on_menu_saveas_activate (GtkWidget *widget, void* user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_export_activate (GtkWidget *widget, void * user) {
+void on_menu_export_activate (GtkWidget *widget, void *user) {
     gchar* filename = NULL;
 
     filename = get_save_filename (TYPE_PDF);
@@ -109,7 +143,7 @@ void on_menu_export_activate (GtkWidget *widget, void * user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_recent_activate (GtkWidget *widget, void * user) {
+void on_menu_recent_activate (GtkWidget *widget, void *user) {
     const gchar* name = gtk_menu_item_get_label (GTK_MENU_ITEM (widget));
     gchar* tstr;
     gint index = name[0] - '0' -1;
@@ -148,11 +182,15 @@ void on_menu_close_activate (GtkWidget *widget, void* user) {
     else if (GTK_RESPONSE_CANCEL == ret || GTK_RESPONSE_DELETE_EVENT == ret)
         return;
     
+    /* Kill typesetter command */
+    motion_kill_typesetter(gummi->motion);
+
     if (!tabmanager_remove_tab (tab)) {
         motion_start_errormode (gummi->motion, "");
         gui_set_hastabs_sensitive (FALSE);
-    } else
+    } else {
         gui_set_filename_display (g_active_tab, TRUE, FALSE);
+    }
 }
 
 G_MODULE_EXPORT
@@ -239,19 +277,19 @@ void on_menu_paste_activate (GtkWidget *widget, void* user) {
 
 
 G_MODULE_EXPORT
-void on_menu_delete_activate (GtkWidget *widget, void * user) {
+void on_menu_delete_activate (GtkWidget *widget, void *user) {
     gtk_text_buffer_delete_selection (g_e_buffer, FALSE, TRUE);
 }
 
 G_MODULE_EXPORT
-void on_menu_selectall_activate (GtkWidget *widget, void * user) {
+void on_menu_selectall_activate (GtkWidget *widget, void *user) {
     GtkTextIter start, end;
     gtk_text_buffer_get_bounds (g_e_buffer, &start, &end);
     gtk_text_buffer_select_range (g_e_buffer, &start, &end);
 }
 
 G_MODULE_EXPORT
-void on_menu_preferences_activate (GtkWidget *widget, void * user) {
+void on_menu_preferences_activate (GtkWidget *widget, void *user) {
     prefsgui_main (gui->prefsgui, 0);
 }
 
@@ -260,7 +298,7 @@ void on_menu_preferences_activate (GtkWidget *widget, void * user) {
  ******************************************************************************/
 
 G_MODULE_EXPORT
-void on_menu_statusbar_toggled (GtkWidget *widget, void * user) {
+void on_menu_statusbar_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         gtk_widget_show (GTK_WIDGET (gui->statusbar));
         config_set_value ("statusbar", "True");
@@ -271,18 +309,18 @@ void on_menu_statusbar_toggled (GtkWidget *widget, void * user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_toolbar_toggled (GtkWidget *widget, void * user) {
+void on_menu_toolbar_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
-        gtk_widget_show (GTK_WIDGET (gui->toolbar));
+        gtk_widget_show (gui->toolbar);
         config_set_value ("toolbar", "True");
     } else {
-        gtk_widget_hide (GTK_WIDGET (gui->toolbar));
+        gtk_widget_hide (gui->toolbar);
         config_set_value ("toolbar", "False");
     }
 }
 
 G_MODULE_EXPORT
-void on_menu_rightpane_toggled (GtkWidget *widget, void * user) {
+void on_menu_rightpane_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         gtk_widget_show (GTK_WIDGET (gui->rightpane));
         config_set_value ("rightpane", "True");
@@ -295,7 +333,7 @@ void on_menu_rightpane_toggled (GtkWidget *widget, void * user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_fullscreen_toggled (GtkWidget *widget, void * user) {
+void on_menu_fullscreen_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget)))
         gtk_window_fullscreen (gui->mainwindow);
     else
@@ -312,12 +350,12 @@ void on_menu_find_activate (GtkWidget *widget, void* user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_findnext_activate (GtkWidget *widget, void * user) {
+void on_menu_findnext_activate (GtkWidget *widget, void *user) {
     editor_jumpto_search_result (g_active_editor, 1);
 }
 
 G_MODULE_EXPORT
-void on_menu_findprev_activate (GtkWidget *widget, void * user) {
+void on_menu_findprev_activate (GtkWidget *widget, void *user) {
     editor_jumpto_search_result (g_active_editor, -1);
 }
 
@@ -337,7 +375,19 @@ void on_menu_compileopts_activate (GtkWidget* widget, void* user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_runmakeindex_activate (GtkWidget *widget, void * user) {
+void on_menu_cleanup_activate (GtkWidget *widget, void *user) {
+    int result = latex_remove_auxfile (g_active_editor);
+
+    if (result == 0) {
+        statusbar_set_message (_("Succesfully removed build files.."));
+    }
+    else {
+        statusbar_set_message (_("Error removing build files.."));
+    }
+}
+
+G_MODULE_EXPORT
+void on_menu_runmakeindex_activate (GtkWidget *widget, void *user) {
     if (latex_run_makeindex (g_active_editor)) {
         statusbar_set_message (_("Running Makeindex.."));
     }
@@ -347,19 +397,13 @@ void on_menu_runmakeindex_activate (GtkWidget *widget, void * user) {
     motion_force_compile (gummi->motion);
 }
 
-
-
-
-
-
-
 G_MODULE_EXPORT
-void on_menu_runbibtex_activate (GtkWidget *widget, void * user) {
+void on_menu_runbibtex_activate (GtkWidget *widget, void *user) {
     on_button_biblio_compile_clicked (widget, user);
 }
 
 G_MODULE_EXPORT
-void on_menu_docstat_activate (GtkWidget *widget, void * user) {
+void on_menu_docstat_activate (GtkWidget *widget, void *user) {
     gint i = 0;
     gchar* output = 0;
     gchar* cmd = 0;
@@ -405,7 +449,7 @@ void on_menu_docstat_activate (GtkWidget *widget, void * user) {
         }
 
         cmd = g_strdup_printf ("texcount '%s'", tmpfile);
-        Tuple2 result = utils_popen_r (cmd);
+        Tuple2 result = utils_popen_r (cmd, NULL);
 
         for (i = 0; i < TEXCOUNT_OUTPUT_LINES; ++i)
             if (! (regexs[i] = g_regex_new (terms_regex[i], 0, 0, &err))) {
@@ -464,7 +508,7 @@ cleanup:
 }
 
 G_MODULE_EXPORT
-void on_menu_spelling_toggled (GtkWidget *widget, void * user) {
+void on_menu_spelling_toggled (GtkWidget *widget, void *user) {
 #ifdef USE_GTKSPELL
     GList *editors;
     GuEditor* ec;
@@ -492,7 +536,7 @@ void on_menu_spelling_toggled (GtkWidget *widget, void * user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_snippets_toggled (GtkWidget *widget, void * user) {
+void on_menu_snippets_toggled (GtkWidget *widget, void *user) {
     if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (widget))) {
         slog(L_INFO, "snippets activated\n");
         config_set_value ("snippets", "True");
@@ -510,15 +554,27 @@ G_MODULE_EXPORT
 void on_menu_project_activate (GtkWidget *widget, void *user) {
     // TODO: perhaps use buffer to run pre compile check */
     
-    g_return_if_fail (g_active_editor != NULL);
-
+    if (g_active_editor == NULL) {
+		gtk_widget_set_tooltip_text (GTK_WIDGET 
+					 (gui->menugui->menu_projcreate),
+					_("This function requires an active document"));
+		return;
+	}
+    
     if (!gummi_project_active()) {
         gtk_widget_set_sensitive (GTK_WIDGET
                                  (gui->menugui->menu_projopen), TRUE);
+        // TODO we should probably have functions for calls like this:
         if (g_active_editor->filename != NULL) {
             gtk_widget_set_sensitive (GTK_WIDGET
-                                 (gui->menugui->menu_projcreate), TRUE);
+                                 (gui->menugui->menu_projcreate), TRUE);                    
         }
+        else {
+			gtk_widget_set_tooltip_text (GTK_WIDGET 
+					 (gui->menugui->menu_projcreate),
+					_("This function requires the current\n"
+					  "active document to be saved. "));
+		}
     }
     else {
         gtk_widget_set_sensitive (GTK_WIDGET
@@ -583,7 +639,19 @@ void on_menu_projclose_activate (GtkWidget *widget, void *user) {
  ******************************************************************************/
 
 G_MODULE_EXPORT
-void on_menu_update_activate (GtkWidget *widget, void * user) {
+void on_menu_guide_activate (GtkWidget *widget, void *user) {
+    GError *error = NULL;
+
+    gtk_show_uri (gdk_screen_get_default(), 
+                  C_GUMMIGUIDE, GDK_CURRENT_TIME, &error);
+    
+    if (error) {
+        slog (L_ERROR, "Can't open user guide: %s\n", error->message);
+    }
+}
+
+G_MODULE_EXPORT
+void on_menu_update_activate (GtkWidget *widget, void *user) {
     #ifdef WIN32
         slog (L_G_INFO, "To be implemented for win32..\n");
     #else
@@ -594,7 +662,7 @@ void on_menu_update_activate (GtkWidget *widget, void * user) {
 }
 
 G_MODULE_EXPORT
-void on_menu_about_activate (GtkWidget *widget, void * user) {
+void on_menu_about_activate (GtkWidget *widget, void *user) {
     GError* err = NULL;
     gchar* icon_file = g_build_filename (DATADIR, "icons", "gummi.png", NULL);
     GdkPixbuf* icon = gdk_pixbuf_new_from_file_at_size (icon_file, 80, 80, &err);
@@ -617,6 +685,7 @@ void on_menu_about_activate (GtkWidget *widget, void * user) {
         "Arabic: Hamad Mohammad\n"
         "Brazilian-Portugese: Fernando Cruz & Alexandre Guimarães\n"
         "Catalan: Marc Vinyals\n"
+        "Chinese (Simplified): Mathlab pass\n"
         "Chinese (Traditional): Wei-Ning Huang\n"
         "Czech: Přemysl Janouch\n"
         "Danish: Jack Olsen\n"
@@ -631,6 +700,8 @@ void on_menu_about_activate (GtkWidget *widget, void * user) {
         "Russian: Kruvalig\n"
         "Swedish: Kess Vargavind\n"
         "Spanish: Carlos Salas Contreras\n";
+        
+    const gchar* documenters[] = {"Guy Edwards", NULL};
 
     GtkAboutDialog* dialog = GTK_ABOUT_DIALOG (gtk_about_dialog_new ());
     gtk_window_set_transient_for (GTK_WINDOW (dialog), gui->mainwindow);
@@ -644,6 +715,7 @@ void on_menu_about_activate (GtkWidget *widget, void * user) {
     gtk_about_dialog_set_logo (dialog, icon);
     gtk_about_dialog_set_comments (dialog, PACKAGE_COMMENTS);
     gtk_about_dialog_set_translator_credits (dialog, translators);
+    gtk_about_dialog_set_documenters (dialog, documenters);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (GTK_WIDGET (dialog));
 }
