@@ -2,7 +2,7 @@
  * @file   gui-prefs.c
  * @brief
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -149,19 +149,26 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
 
 #ifdef USE_GTKSPELL
     /* list available languages */
-    gchar* ptr = 0;
 
-    Tuple2 pret = utils_popen_r ("enchant-lsmod -list-dicts");
+    Tuple2 pret = utils_popen_r ("enchant-lsmod -list-dicts", NULL);
 
-    ptr = strtok ((gchar*)pret.second, " \n");
-    while (ptr) {
-        GtkTreeIter iter;
-        if (ptr[0] != '(') {
-            gtk_list_store_append (p->list_languages, &iter);
-            gtk_list_store_set (p->list_languages, &iter, 0, ptr, -1);
+    if (pret.second != NULL) {
+        gchar** output = g_strsplit((gchar*)pret.second, "\n", BUFSIZ);
+        gchar** elems = NULL;
+        int i;
+
+        for(i = 0; output[i] != NULL; i++) {
+            GtkTreeIter iter;
+            elems = g_strsplit (output[i], " ", BUFSIZ);
+            if (elems[0] != NULL) {
+                gtk_list_store_append (p->list_languages, &iter);
+                gtk_list_store_set (p->list_languages, &iter, 0, elems[0], -1);
+            }
         }
-        ptr = strtok (NULL, " \n");
+    g_strfreev(output);
+    g_strfreev(elems);
     }
+
     gtk_combo_box_set_active (p->combo_languages, 0);
     g_free ((gchar*)pret.second);
 #else
@@ -265,6 +272,7 @@ static void set_tab_defaulttext_settings (GuPrefsGui* prefs) {
         return;
     }
     gtk_text_buffer_set_text (prefs->default_buffer, text, -1);
+    gtk_text_buffer_set_modified (prefs->default_buffer, FALSE);
     g_free (text);
 }
 
@@ -339,12 +347,12 @@ static void set_tab_preview_settings (GuPrefsGui* prefs) {
     gtk_spin_button_set_value (prefs->compile_timer,
                                atoi (config_get_value ("compile_timer")));
     /* compile scheme */
-    if (0 == g_strcmp0 (config_get_value ("compile_scheme"), "real_time"))
+    if (STR_EQU (config_get_value ("compile_scheme"), "real_time"))
         gtk_combo_box_set_active (prefs->compile_scheme, 1);
                                
-    if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "always")) {
+    if (STR_EQU (config_get_value ("animated_scroll"), "always")) {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 0);
-    } else if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "never")) {
+    } else if (STR_EQU (config_get_value ("animated_scroll"), "never")) {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 2);
     } else {
         gtk_combo_box_set_active (prefs->combo_animated_scroll, 1);
@@ -368,7 +376,7 @@ static void set_tab_miscellaneous_settings (GuPrefsGui* prefs) {
     while (valid) {
         const gchar* str_value;
         gtk_tree_model_get (combo_lang, &iter, 0, &str_value, -1);
-        if (0 == g_strcmp0 (lang, str_value)) {
+        if (STR_EQU (lang, str_value)) {
             gtk_combo_box_set_active (prefs->combo_languages, count);
             break;
         }
@@ -390,7 +398,7 @@ void prefsgui_apply_style_scheme(GuPrefsGui* prefs) {
     GtkTreePath* treepath;
 
     while (schemes_iter) {
-        if (!g_strcmp0 (gtk_source_style_scheme_get_id (schemes_iter->data),
+        if (STR_EQU (gtk_source_style_scheme_get_id (schemes_iter->data),
                      scheme)) {
             gchar* path = g_strdup_printf ("%d", column);
             treepath = gtk_tree_path_new_from_string (path);
