@@ -2,7 +2,7 @@
  * @file    gui-preview.c
  * @brief 
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -245,8 +245,14 @@ GuPreviewGui* previewgui_init (GtkBuilder * builder) {
     g_object_unref(holder);
 
     // The scale to correct for the users DPI
-    gdouble poppler_scale = gdk_screen_get_resolution(
-            gdk_screen_get_default()) / 72.0;
+    gdouble screen_dpi = gdk_screen_get_resolution (
+						 gdk_screen_get_default());
+            
+	/* the gdk screen functions do not work properly on win32, so we 
+	 * should probably return a default value (or find an alternative)*/
+    if (screen_dpi == -1) screen_dpi = 96.0;
+	gdouble poppler_scale = screen_dpi / 72.0;
+
     int i;
     for (i=0; i<N_ZOOM_SIZES; i++) {
         list_sizes[i] *= poppler_scale;
@@ -256,19 +262,19 @@ GuPreviewGui* previewgui_init (GtkBuilder * builder) {
     
     /* TODO: temporary measure because the config system does not look up
              default value if the setting is undefined */
-    if (utils_strequal (config_get_value("zoommode"), "")) {
+    if (STR_EQU (config_get_value("zoommode"), "")) {
         config_set_value("zoommode", "pagewidth");
     }
     
-    if (utils_strequal (config_get_value("animated_scroll"), "")) {
+    if (STR_EQU (config_get_value("animated_scroll"), "")) {
         config_set_value("animated_scroll", "always");
     }
     
-    if (utils_strequal (config_get_value("cache_size"), "")) {
+    if (STR_EQU (config_get_value("cache_size"), "")) {
         config_set_value("cache_size", "150");
     }
 
-    if (g_strcmp0 (config_get_value ("pagelayout"), "single_page") == 0) {
+    if (STR_EQU (config_get_value ("pagelayout"), "single_page")) {
         gtk_check_menu_item_set_active(
                 GTK_CHECK_MENU_ITEM(p->page_layout_single_page), TRUE);
         p->pageLayout = POPPLER_PAGE_LAYOUT_SINGLE_PAGE;
@@ -936,13 +942,13 @@ void previewgui_set_pdffile (GuPreviewGui* pc, const gchar *pdffile) {
 
     // Restore scale and fit mode
     g_signal_handler_block(pc->combo_sizes, pc->combo_sizes_changed_handler);
-    if (g_strcmp0 (config_get_value ("zoommode"), "pagewidth") == 0) {
+    if (STR_EQU (config_get_value ("zoommode"), "pagewidth")) {
         set_fit_mode(pc, FIT_WIDTH);
         gtk_combo_box_set_active(pc->combo_sizes, ZOOM_FIT_WIDTH);
-    } else if (g_strcmp0 (config_get_value ("zoommode"), "pageheight") == 0) {
+    } else if (STR_EQU (config_get_value ("zoommode"), "pageheight")) {
         set_fit_mode(pc, FIT_HEIGHT);
         //gtk_combo_box_set_active(pc->combo_sizes, new_index);
-    } else if (g_strcmp0 (config_get_value ("zoommode"), "bestfit") == 0) {
+    } else if (STR_EQU (config_get_value ("zoommode"), "bestfit")) {
         set_fit_mode(pc, FIT_BOTH);
         gtk_combo_box_set_active(pc->combo_sizes, ZOOM_FIT_BOTH);
     } else {
@@ -955,10 +961,9 @@ void previewgui_set_pdffile (GuPreviewGui* pc, const gchar *pdffile) {
     }
     g_signal_handler_unblock(pc->combo_sizes, pc->combo_sizes_changed_handler);
 
-    // Dion: I believe this line caused Bug #252 
-    // It was only for the case where the first page is not at the top left 
-    // (it is not as wide as the others or we are in two paged layout).
-    //previewgui_goto_page (pc, 0);
+    gtk_widget_queue_draw (pc->drawarea);
+    
+    previewgui_goto_page (pc, 0);
 }
 
 void previewgui_refresh (GuPreviewGui* pc, GtkTextIter *sync_to,
@@ -1256,58 +1261,53 @@ static void synctex_scroll_to_node(GuPreviewGui* pc, SyncNode* node) {
     gdouble node_height = node->height * pc->scale;
     gdouble node_width = node->width * pc->scale;
 
-    gdouble target_x = gtk_adjustment_get_value(pc->hadj);
-    gdouble target_width = adjpage_width;
-    gdouble target_y = gtk_adjustment_get_value(pc->vadj) + adjpage_height/3;
-    gdouble target_height = adjpage_height/3;
+    gdouble view_x = gtk_adjustment_get_value(pc->hadj);
+    gdouble view_width = adjpage_width;
+    gdouble view_y = gtk_adjustment_get_value(pc->vadj);
+    gdouble view_height = adjpage_height;
     
-    gdouble diff_top = node_y - target_y;
-    gdouble diff_left = node_x - target_x;
-    gdouble diff_bottom = target_y + target_height - (node_y+node_height);
-    gdouble diff_right = target_x + target_width - (node_x+node_width);
-    
-    slog(L_DEBUG, "node: (%f, %f), w=%f, h=%f\n", node_x, node_y, node_width, node_height);
-    slog(L_DEBUG, "target: (%f, %f), w=%f, h=%f\n", target_x, target_y, target_width, target_height);
-    
-    slog(L_DEBUG, "diff: top=%f, left=%f, bottom=%f, right=%f\n", diff_top, diff_left, diff_bottom, diff_right);
-        
-    gdouble to_y = gtk_adjustment_get_value(pc->vadj);
-    gdouble to_x = gtk_adjustment_get_value(pc->hadj);
-    
-    if (floor(diff_top) < 0) {
-        to_y = node_y + node_height - target_height;
-    } else if (floor(diff_bottom) < 0) {
+    slog(L_DEBUG, "node: (%f, %f), w=%f, h=%f\n", node_x, node_y, node_width,
+            node_height);
+    slog(L_DEBUG, "view: (%f, %f), w=%f, h=%f\n", view_x, view_y,
+        view_width, view_height);
+
+    gdouble to_y;
+    gdouble to_x;
+    // Positioning algorithm:
+    // The x and y coordinates are treated separately.  For each,
+    //  - If the node is already within the view, do not change the view.
+    //  - Else, if the node can fit in the view, center it.
+    //  - Else, align the view to the top/left of the view.
+    // The functions used to change the view do bounds checking, so we
+    // don't do that here.
+
+    if (node_y > view_y && node_y + node_height < view_y + view_height) {
+        to_y = view_y;
+    } else if (node_height < view_height) {
+        to_y = node_y + (node_height - view_height)/2;
+    } else {
         to_y = node_y;
     }
-    
-    if (floor(diff_left) < 0 && floor(diff_right) > 0) {
-        to_x += MIN(ABS(diff_left), ABS(diff_right));
-    } else if (floor(diff_left) > 0 && floor(diff_right) < 0) {
-        to_x -= MIN(ABS(diff_left), ABS(diff_right));
+        
+    if (node_x > view_x && node_x + node_width < view_x + view_width) {
+        to_x = view_x;
+    } else if (node_width < view_width) {
+        to_x = node_x + (node_width - view_width)/2;
+    } else {
+        to_x = node_x;
     }
     
     if (!is_continuous(pc) && pc->current_page != node->page) {
     
         previewgui_goto_page (pc, node->page);
-        
-        to_y = to_y - (adjpage_height - target_height)/2;
-        to_x = to_x - (adjpage_width - target_width)/2;
-        
         previewgui_goto_xy(pc, to_x, to_y);
     
     } else {
-        if (to_y != gtk_adjustment_get_value(pc->vadj) || 
-            to_x != gtk_adjustment_get_value(pc->hadj)) {
-            
-            to_y = to_y - (adjpage_height - target_height)/2;
-            to_x = to_x - (adjpage_width - target_width)/2;
-            
-            if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "always") || 
-                0 == g_strcmp0 (config_get_value ("animated_scroll"), "autosync")) {
-                previewgui_scroll_to_xy(pc, to_x, to_y);
-            } else {
-                previewgui_goto_xy(pc, to_x, to_y);
-            }
+        if (STR_EQU (config_get_value ("animated_scroll"), "always") ||
+            STR_EQU (config_get_value ("animated_scroll"), "autosync")) {
+            previewgui_scroll_to_xy(pc, to_x, to_y);
+        } else {
+            previewgui_goto_xy(pc, to_x, to_y);
         }
     }
 
@@ -1501,7 +1501,7 @@ void previewgui_cleanup_fds (GuPreviewGui* pc) {
 }
 
 void previewgui_start_preview (GuPreviewGui* pc) {
-    if (0 == g_strcmp0 (config_get_value ("compile_scheme"), "on_idle")) {
+    if (STR_EQU (config_get_value ("compile_scheme"), "on_idle")) {
         pc->preview_on_idle = TRUE;
     } else {
         pc->update_timer = g_timeout_add_seconds (
@@ -1526,7 +1526,7 @@ void on_page_input_changed (GtkEntry* entry, void* user) {
     newpage = MAX(newpage, 0);
     newpage = MIN(newpage, gui->previewgui->n_pages);
     
-    if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "always")) {
+    if (STR_EQU (config_get_value ("animated_scroll"), "always")) {
         previewgui_scroll_to_page (gui->previewgui, newpage);
     } else {
         previewgui_goto_page (gui->previewgui, newpage);
@@ -1539,7 +1539,7 @@ void on_next_page_clicked (GtkWidget* widget, void* user) {
     //L_F_DEBUG;
     GuPreviewGui *pc = gui->previewgui;
 
-    if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "always")) {
+    if (STR_EQU (config_get_value ("animated_scroll"), "always")) {
         previewgui_scroll_to_page (pc, pc->next_page);
     } else {
         previewgui_goto_page (pc, pc->next_page);
@@ -1551,7 +1551,7 @@ void on_prev_page_clicked (GtkWidget* widget, void* user) {
     //L_F_DEBUG;
     GuPreviewGui *pc = gui->previewgui;
 
-    if (0 == g_strcmp0 (config_get_value ("animated_scroll"), "always")) {
+    if (STR_EQU (config_get_value ("animated_scroll"), "always")) {
         previewgui_scroll_to_page (pc, pc->prev_page);
     } else {
         previewgui_goto_page (pc, pc->prev_page);
