@@ -2,7 +2,7 @@
  * @file    iofunctions.c
  * @brief  
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -173,6 +173,31 @@ void iofunctions_real_save_file (GObject* hook, GObject* savecontext) {
     g_object_unref (savecontext);
 }
 
+gchar* iofunctions_get_swapfile (const gchar* filename) {
+    gchar* basename = NULL;
+    gchar* dirname = NULL;
+    gchar* swapfile = NULL;
+    
+    basename = g_path_get_basename (filename);
+    dirname = g_path_get_dirname (filename);
+    swapfile = g_strdup_printf ("%s%c.%s.swp", dirname,
+            G_DIR_SEPARATOR, basename);
+            
+    g_free (dirname);
+    g_free (basename);
+    return swapfile;
+}
+
+gboolean iofunctions_has_swapfile (const gchar* filename) {
+    if (filename == NULL) return FALSE;
+    
+    gchar* swapfile = iofunctions_get_swapfile (filename);
+    if (utils_path_exists (swapfile)) {
+        return TRUE;
+    }
+    return FALSE;
+}
+
 void iofunctions_start_autosave (void) {
     sid = g_timeout_add_seconds (atoi(config_get_value ("autosave_timer")) * 60,
             iofunctions_autosave_cb, NULL);
