@@ -2,7 +2,7 @@
  * @file   latex.c
  * @brief  
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -36,6 +36,7 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #include "configfile.h"
 #include "constants.h"
@@ -72,7 +73,7 @@ GuLatex* latex_init (void) {
 
 
 gboolean latex_method_active (gchar* method) {
-    if (utils_strequal (config_get_value ("compile_steps"), method)) {
+    if (STR_EQU (config_get_value ("compile_steps"), method)) {
         return TRUE;
     }
     return FALSE;
@@ -83,22 +84,19 @@ gchar* latex_update_workfile (GuLatex* lc, GuEditor* ec) {
     
     text = editor_grab_buffer (ec);
     
-    /* write buffer content to the workfile */
-    utils_set_file_contents (ec->workfile, text, -1);
-    
+    // bit of a dirty hack, but only write the buffer content when
+    // there is not a recovery in progress, otherwise the workfile
+    // will be overwritten with empty text
+    if (!STR_EQU (text, "")) {
+        utils_set_file_contents (ec->workfile, text, -1);
+    }
     return text;
 }
 
-
-
-
 gchar* latex_set_compile_cmd (GuEditor* ec) {
     
     const gchar* method = config_get_value ("compile_steps");
-    const gchar* curdir = g_path_get_dirname (ec->workfile);
-    const gchar* precommand = g_strdup_printf ("cd \"%s\"%s%s", 
-                                                curdir, C_CMDSEP, C_TEXSEC);
-                                                
+    gchar* combined = NULL;
     gchar* texcmd = NULL;
     
     if (rubber_active()) {
@@ -111,11 +109,8 @@ gchar* latex_set_compile_cmd (GuEditor* ec) {
         texcmd = texlive_get_command (method, ec->workfile, ec->basename);
     }
 
-    gchar* combined = g_strdup_printf ("%s %s", 
-                                        precommand, 
-                                        texcmd);
-                                        
-    //printf("%s\n", combined);
+    combined = g_strdup_printf("%s %s", C_TEXSEC, texcmd);
+    g_free(texcmd);
 
     return combined;
 }
@@ -184,13 +179,14 @@ gboolean latex_update_pdffile (GuLatex* lc, GuEditor* ec) {
     }
 
     /* create compile command */
+    gchar* curdir = g_path_get_dirname (ec->workfile);
     gchar *command = latex_set_compile_cmd (ec);
 
     g_free (lc->compilelog);
     memset (lc->errorlines, 0, BUFSIZ);
     
     /* run pdf compilation */
-    Tuple2 cresult = utils_popen_r (command);
+    Tuple2 cresult = utils_popen_r (command, curdir);
     cerrors = (glong)cresult.first;
     gchar* coutput = (gchar*)cresult.second;
     
@@ -209,23 +205,41 @@ gboolean latex_update_pdffile (GuLatex* lc, GuEditor* ec) {
 
 void latex_update_auxfile (GuLatex* lc, GuEditor* ec) {
     gchar* dirname = g_path_get_dirname (ec->workfile);
-    gchar* command = g_strdup_printf ("cd \"%s\"%s"
-                                     "%s %s "
-                                     "--draftmode "
-                                     "-interaction=nonstopmode "
-                                     "--output-directory=\"%s\" \"%s\"",
-                                     dirname,
-                                     C_CMDSEP,
-                                     C_TEXSEC,
-                                     config_get_value ("typesetter"),
-                                     C_TMPDIR,
-                                     ec->workfile);
+    gchar* command = g_strdup_printf ("%s %s "
+                                      "--draftmode "
+                                      "-interaction=nonstopmode "
+                                      "--output-directory=\"%s\" \"%s\"",
+                                      C_TEXSEC,
+                                      config_get_value ("typesetter"),
+                                      C_TMPDIR,
+                                      ec->workfile);
+    Tuple2 res = utils_popen_r (command, dirname);
     g_free (dirname);
-    Tuple2 res = utils_popen_r (command);
     g_free (res.second);
     g_free (command);
 }
 
+int latex_remove_auxfile (GuEditor* ec) {
+    gchar* auxfile = NULL;
+    int res = -1;
+    // TODO: merge this into function with several other instances.
+    // for instance the lines in analyse_log
+    if (ec->filename == NULL) {
+        auxfile = g_strconcat (ec->basename, ".aux", NULL);
+    }
+    else {
+        auxfile = g_strconcat (C_TMPDIR, C_DIRSEP, 
+                  g_path_get_basename(ec->basename), ".aux", NULL);
+        }
+    
+    // TODO: extend for other build files
+    if (g_file_test (auxfile, G_FILE_TEST_EXISTS)) {
+        res = g_remove (auxfile);
+    }
+    g_free (auxfile);
+    return res;
+}
+
 gboolean latex_precompile_check (gchar* editortext) {
     /* both documentclass and documentstyle appear to be valid.
      * http://pangea.stanford.edu/computing/unix/formatting/parts.php
@@ -247,7 +261,7 @@ void latex_export_pdffile (GuLatex* lc, GuEditor* ec, const gchar* path,
     GError* err = NULL;
     gint ret = 0;
 
-    if (0 != g_strcmp0 (path + strlen (path) -4, ".pdf"))
+    if (!STR_EQU (path + strlen (path) -4, ".pdf"))
         savepath = g_strdup_printf ("%s.pdf", path);
     else
         savepath = g_strdup (path);
@@ -273,14 +287,11 @@ gboolean latex_run_makeindex (GuEditor* ec) {
     
     if (g_find_program_in_path ("makeindex")) {
         
-        const gchar* precmd = g_strdup_printf ("cd \"%s\"%s%s", 
-                                                C_TMPDIR, C_CMDSEP, C_TEXSEC);
-                                                    
         gchar* command = g_strdup_printf ("%s makeindex \"%s.idx\"",
-                                         precmd, 
-                                         g_path_get_basename(ec->basename));
+                                          C_TEXSEC,
+                                          g_path_get_basename(ec->basename));
                                          
-        Tuple2 res = utils_popen_r (command);
+        Tuple2 res = utils_popen_r (command, C_TMPDIR);
         retcode = (glong)res.first;
         g_free (command);
     }
