@@ -2,7 +2,7 @@
  * @file   motion.c
  * @brief  
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -31,6 +31,12 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <signal.h>
+
+#ifndef WIN32
+    #include <sys/types.h>
+    #include <sys/wait.h>
+#endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -47,6 +53,9 @@
 extern GummiGui* gui;
 extern Gummi* gummi;
 
+/* Typesetter pid */
+pid_t typesetter_pid = 0;
+
 GuMotion* motion_init (void) {
     GuMotion* m = g_new0 (GuMotion, 1);
 
@@ -55,6 +64,7 @@ GuMotion* motion_init (void) {
     m->compile_mutex = g_mutex_new ();
     m->compile_cv = g_cond_new ();
     m->keep_running = TRUE;
+    m->typesetter_pid = &typesetter_pid;
 
     return m;
 }
@@ -76,6 +86,30 @@ void motion_stop_compile_thread (GuMotion* m) {
     g_thread_join(m->compile_thread);
 }
 
+void motion_kill_typesetter (GuMotion* m) {
+    if (*m->typesetter_pid) {
+        gchar* command = NULL;
+        /* Kill children spawned by typesetter command/script, don't know
+         * how to do this programatically yet(glib doesn't not provides any
+         * function for killing a process), so use pkill for now. For
+         * win32 there's currently nothing we can do about it. */
+#ifndef WIN32
+        command = g_strdup_printf("pkill -15 -P %d", *m->typesetter_pid);
+        system(command);
+        g_free(command);
+
+        /* Make sure typesetter command is terminated */
+        kill(*m->typesetter_pid, 15);
+#endif
+
+        slog(L_DEBUG, "Typeseter[pid=%d]: Killed\n", *m->typesetter_pid);
+        *m->typesetter_pid = 0;
+
+        /* XXX: Ugly hack: delay compile signal */
+        motion_start_timer (m);
+    }
+}
+
 gboolean motion_do_compile (gpointer user) {
     L_F_DEBUG;
     GuMotion* mc = GU_MOTION (user);
@@ -85,7 +119,7 @@ gboolean motion_do_compile (gpointer user) {
     g_mutex_unlock (mc->signal_mutex);
 
 ret:
-    return (0 == g_strcmp0 (config_get_value ("compile_scheme"), "real_time"));
+    return (STR_EQU (config_get_value ("compile_scheme"), "real_time"));
 }
 
 gpointer motion_compile_thread (gpointer data) {
@@ -136,6 +170,7 @@ gpointer motion_compile_thread (gpointer data) {
         }
         
         compile_status = latex_update_pdffile (latex, editor);
+        *mc->typesetter_pid = 0;
         g_mutex_unlock (mc->compile_mutex);
 
         if (!mc->keep_running)
@@ -170,7 +205,7 @@ void motion_force_compile (GuMotion *mc) {
     /* sort-of signal to force a compile run after certain actions that
      * don't trigger the regular editor content change signals */
     gummi->latex->modified_since_compile = TRUE;
-    motion_start_timer (gummi->motion);
+    motion_do_compile (mc);
 }
 
 void motion_start_errormode (GuMotion *mc, const gchar *msg) {
