@@ -2,7 +2,7 @@
  * @file   motion.h
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -42,6 +42,7 @@ struct _GuMotion {
     GMutex* compile_mutex;
     GThread* compile_thread;
     GCond* compile_cv;
+    pid_t* typesetter_pid;
     
     gboolean keep_running;
     gboolean errormode;
@@ -56,16 +57,13 @@ gpointer motion_compile_thread (gpointer data);
 gboolean motion_idle_cb (gpointer user);
 void motion_start_timer (GuMotion* mc);
 void motion_stop_timer (GuMotion* mc);
-
-
+void motion_kill_typesetter (GuMotion* m);
 
 void motion_start_errormode (GuMotion *mc, const gchar *msg);
 void motion_stop_errormode (GuMotion *mc);
 
-
 gboolean on_key_press_cb (GtkWidget* widget, GdkEventKey* event, void* user);
 gboolean on_key_release_cb (GtkWidget* widget, GdkEventKey* event, void* user);
 
 
-
 #endif /* __GUMMI_MOTION_H__ */
