@@ -2,7 +2,7 @@
  * @file    snippets.c
  * @brief   handle snppets
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -356,6 +356,15 @@ GuSnippetInfo* snippets_parse (char* snippet) {
         while (g_match_info_matches (match_info)) {
             result = g_match_info_fetch_all (match_info);
             g_match_info_fetch_pos (match_info, 0, &start, &end);
+
+            /* Convert start, end to UTF8 offset */
+            char* s_start = g_substr(snippet, 0, start);
+            char* s_end = g_substr(snippet, 0, end);
+            start = g_utf8_strlen(s_start, -1);
+            end = g_utf8_strlen(s_end, -1);
+            g_free(s_start);
+            g_free(s_end);
+
             if (i < 2) {
                 snippet_info_append_holder (info, atoi (result[1]), start,
                         end -start, result[2]);
@@ -411,7 +420,7 @@ void snippets_accel_disconnect (GuSnippets* sc, const gchar* key) {
     current = sc->closure_data;
     while (current) {
         closure_data = TUPLE2 (current->data);
-        if (g_strcmp0 (closure_data->first, key) == 0)
+        if (STR_EQU (closure_data->first, key))
             break;
         current = g_list_next (current);
     }
@@ -578,7 +587,7 @@ void snippet_info_initial_expand (GuSnippetInfo* info, GuEditor* ec) {
 
         /* Expand macros */
         text = GU_SNIPPET_EXPAND_INFO(current->data)->text;
-        if (g_strcmp0 (text, "SELECTED_TEXT") == 0) {
+        if (STR_EQU (text, "SELECTED_TEXT")) {
             GtkTextIter ms, me;
             gtk_text_buffer_delete (ec_buffer, &start, &end);
             gtk_text_buffer_insert (ec_buffer, &start, info->sel_text, -1);
@@ -586,11 +595,11 @@ void snippet_info_initial_expand (GuSnippetInfo* info, GuEditor* ec) {
             me = ms;
             gtk_text_iter_forward_chars (&me, strlen (info->sel_text));
             gtk_text_buffer_delete (ec_buffer, &ms, &me);
-        } else if (g_strcmp0 (text, "FILENAME") == 0) {
+        } else if (STR_EQU (text, "FILENAME")) {
             gtk_text_buffer_delete (ec_buffer, &start, &end);
             gtk_text_buffer_insert (ec_buffer, &start,
                     ec->filename? ec->filename: "", -1);
-        } else if (g_strcmp0 (text, "BASENAME") == 0) {
+        } else if (STR_EQU (text, "BASENAME")) {
             gchar* basename = g_path_get_basename(ec->filename?ec->filename:"");
             gtk_text_buffer_delete (ec_buffer, &start, &end);
             gtk_text_buffer_insert (ec_buffer, &start, basename, -1);
