@@ -2,7 +2,7 @@
  * @file    utils.c
  * @brief   
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
  * All Rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person
@@ -37,15 +37,17 @@
 #include <glib/gprintf.h>
 #include <gtk/gtk.h>
 #include <unistd.h>
-#include <sys/types.h>
 
-#ifdef HAVE_SYS_WAIT_H
-#   include <sys/wait.h>
+#ifndef WIN32
+    #include <sys/types.h>
+    #include <sys/wait.h>
 #endif
+
 #ifndef WEXITSTATUS
 #   define WEXITSTATUS(stat_val) ((unsigned int) (stat_val) >> 8)
 #endif
 
+#include "constants.h"
 #include "environment.h"
 #include "utils.h"
 
@@ -69,6 +71,8 @@
 static gint slog_debug = 0;
 static GtkWindow* parent = 0;
 GThread* main_thread = 0;
+extern pid_t typesetter_pid;
+
 
 void slog_init (gint debug) {
     slog_debug = debug;
@@ -177,18 +181,9 @@ gboolean utils_path_exists (const gchar* path) {
 
 gboolean utils_set_file_contents (const gchar *filename, const gchar *text,
                                   gssize length) {
-    /* g_file_set_contents does not work properly on Windows systems.
-     * I'm not convinced this current implementation for win32 is 
-     * correct or even solves the problem, so fix/modify away..! */
-    #ifdef WIN32
-        FILE *fp;
-        gint len;
-        len = strlen(text);
-        
-        fp = g_fopen(filename, "w");
-        fwrite(text, sizeof(gchar), len, fp);
-        fclose(fp);
-    #else
+    /* g_file_set_contents may not work correctly on Windows. See the
+     * API documentation of this function for details. Should Gummi
+     * be affected, we might have to implement an alternative */
         GError* error = NULL;
         if (!g_file_set_contents(filename, text, length, &error)) {
             slog (L_ERROR, "%s\n", error->message);
@@ -196,7 +191,6 @@ gboolean utils_set_file_contents (const gchar *filename, const gchar *text,
             return FALSE;
         }
         return TRUE;
-    #endif
 }
 
 gboolean utils_copy_file (const gchar* source, const gchar* dest, GError** err)
@@ -219,18 +213,33 @@ gboolean utils_copy_file (const gchar* source, const gchar* dest, GError** err)
     return TRUE;
 }
 
-Tuple2 utils_popen_r (const gchar* cmd) {
-    FILE* fp = popen (cmd, "r");
+Tuple2 utils_popen_r (const gchar* cmd, const gchar* chdir) {
     gchar buf[BUFSIZ];
+    int pout = 0;
     gchar* ret = NULL;
     gchar* rot = NULL;
-    glong status = 0, len = 0;
+    glong len = 0;
+    gint status = 0;
+    int n_args = 0;
+    gchar** args = NULL;
+    GError* error = NULL;
 
     g_assert (cmd != NULL);
 
-    if (!fp) slog (L_FATAL, "popen () error\n");
+    /* XXX: Set typesetter_pid, ugly... */
+    if (!g_shell_parse_argv(cmd, &n_args, &args, &error)) {
+        slog(L_G_FATAL, "%s", error->message);
+        /* Not reached */
+    }
 
-    while ( (len = fread (buf, 1, BUFSIZ, fp))) {
+    if (!g_spawn_async_with_pipes (chdir, args, NULL,
+                G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+                NULL, NULL, &typesetter_pid, NULL, &pout, NULL, &error)) {
+        slog(L_G_FATAL, "%s", error->message);
+        /* Not reached */
+    }
+
+    while ((len = read (pout, buf, BUFSIZ)) > 0) {
         buf[len - (len == BUFSIZ)] = 0;
         rot = g_strdup (ret);
         g_free (ret);
@@ -239,13 +248,14 @@ Tuple2 utils_popen_r (const gchar* cmd) {
         else
             ret = g_strdup (buf);
         g_free (rot);
-    } /* win32 uses a different range of return codes */
-    #ifdef WIN32
-        status = (pclose (fp));
-    #else
-        status = WEXITSTATUS (pclose (fp));
+    }
+
+    #ifndef WIN32
+        // TODO: command is not available on win32 systems:
+        waitpid(typesetter_pid, &status, 0);
     #endif
-    return (Tuple2){NULL, (gpointer)status, (gpointer)ret};
+
+    return (Tuple2){NULL, (gpointer)(glong)status, (gpointer)ret};
 }
 
 gchar* utils_path_to_relative (const gchar* root, const gchar* target) {
@@ -258,11 +268,11 @@ gchar* utils_path_to_relative (const gchar* root, const gchar* target) {
 }
 
 gchar* utils_get_tmp_tmp_dir (void) {
-/* brb, gonna go punch a wall */
-    gchar *tmp_tmp = "C:\\gummitmp";
+	/* brb, gonna go punch a wall */
+    gchar *tmp_tmp = g_build_path 
+						(C_DIRSEP, g_get_home_dir(), "gtmp", NULL);
     g_mkdir_with_parents (tmp_tmp, DIR_PERMS);
-    /* TODO: find out why Windows's env variables are still
-             using goddamn 8.3 DOS format style and fix it. */
+
     return tmp_tmp;
 }  
 
@@ -272,21 +282,13 @@ gboolean utils_glist_is_member (GList* list, gchar* item) {
     int i;
     
     for (i=0;i<nrofitems;i++) {
-        if (utils_strequal (item, g_list_nth_data (list,i))) {
+        if (STR_EQU (item, g_list_nth_data (list,i))) {
             return TRUE;
         }
     }
     return FALSE;
 }
 
-gboolean utils_strequal (const gchar* str1, const gchar* str2) {
-    /* TODO: replace "g_strcmp0" calls */
-    if (g_strcmp0 (str1, str2) == 0) {
-        return TRUE;
-    }
-    return FALSE;
-}
-
 gboolean utils_subinstr (const gchar* substr, const gchar* target,
         gboolean case_insens) {
     if (target != NULL && substr != NULL) {
@@ -304,7 +306,13 @@ gboolean utils_subinstr (const gchar* substr, const gchar* target,
     }
     return FALSE;
 }
-    
+
+gchar* g_substr(gchar* src, gint start, gint end) {
+    gint len = end - start + 1;
+    char* dst = g_malloc(len * sizeof(gchar));
+    memset(dst, 0, len);
+    return strncpy(dst, &src[start], end - start);
+}
 
 slist* slist_find (slist* head, const gchar* term, gboolean n, gboolean create) {
     slist* current = head;
@@ -315,7 +323,7 @@ slist* slist_find (slist* head, const gchar* term, gboolean n, gboolean create)
             if (0 == strncmp (current->first, term, strlen (term)))
                 return current;
         } else {
-            if (0 == g_strcmp0 (current->first, term))
+            if (STR_EQU (current->first, term))
                 return current;
         }
         prev = current;
